/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
'use strict';

exports.__esModule = true;
exports.default = addEvent;

var _supportsPassiveEvents = _interopRequireDefault(require("./supportsPassiveEvents"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var canUsePassiveEvents = (0, _supportsPassiveEvents.default)();

var emptyFunction = function emptyFunction() {};

var passiveByDefault = {
  touchstart: true,
  touchmove: true,
  scroll: true
};
/**
 * Normalize event options and default performance-sensitive events to passive.
 */

function getOptions(type, options) {
  if (options != null) {
    var capture = options.capture,
        passive = options.passive;

    if (canUsePassiveEvents) {
      return passive == null && passiveByDefault[type] === true ? {
        capture: capture,
        passive: true
      } : options;
    } else {
      return Boolean(capture);
    }
  }

  return false;
}
/**
 * Shim generic API compatibility with ReactDOM's synthetic events, without
 * needing the large amount of code ReactDOM uses to do this. Ideally we
 * wouldn't use a synthetic event wrapper at all.
 */


function isPropagationStopped() {
  return this.cancelBubble;
}

function isDefaultPrevented() {
  return this.defaultPrevented;
}

function normalizeEvent(event) {
  event.nativeEvent = event;
  event.persist = emptyFunction;
  event.isDefaultPrevented = isDefaultPrevented;
  event.isPropagationStopped = isPropagationStopped;
  return event;
}
/**
 * Add the event listener using options normalization, SyntheticEvent
 * compatibility, and returning a function to remove the event listener.
 */


function addEvent(target, type, listener, options) {
  var opts = getOptions(type, options);

  if (listener != null) {
    var element = target;

    var compatListener = function compatListener(e) {
      return listener(normalizeEvent(e));
    };

    element.addEventListener(type, compatListener, opts);
    return function removeListener() {
      if (element != null) {
        element.removeEventListener(type, compatListener, opts);
      }
    };
  } else {
    return emptyFunction;
  }
}

module.exports = exports.default;